import classnames from "classnames/dedupe";
import { __ } from "@wordpress/i18n";
import { createHigherOrderComponent } from "@wordpress/compose";
import { InspectorControls } from "@wordpress/block-editor";
import { PanelBody, SelectControl, ExternalLink } from "@wordpress/components";

const enableSideBarOnBlocks = ["core/button"];

const setSidebarAttribute = (settings, name) => {
  if (!enableSideBarOnBlocks.includes(name)) {
    return settings;
  }
  return Object.assign({}, settings, {
    attributes: Object.assign({}, settings.attributes, {
      buttonIcon: { type: "string" },
      buttonIconAlign: { type: "string", default: "trail" },
    }),
  });
};
wp.hooks.addFilter(
  "blocks.registerBlockType",
  "ucla-wordpress-plugin/set-sidebar-attribute",
  setSidebarAttribute
);

const withSidebarSelect = createHigherOrderComponent((BlockEdit) => {
  return (props) => {
    // If current block is not allowed
    if (!enableSideBarOnBlocks.includes(props.name)) {
      return <BlockEdit {...props} />;
    }

    const { attributes, setAttributes } = props;
    const { buttonIcon, buttonIconAlign } = attributes;

    const iconSelectOption = [
      {
        label: __("None", "ucla-wordpress-plugin"),
        value: "",
      },
      {
        label: __("Menu", "ucla-wordpress-plugin"),
        value: "menu",
      },
      {
        label: __("Close", "ucla-wordpress-plugin"),
        value: "close",
      },
      {
        label: __("Close Circle", "ucla-wordpress-plugin"),
        value: "close-circle-solid",
      },
      {
        label: __("Search", "ucla-wordpress-plugin"),
        value: "search",
      },
      {
        label: __("Chevron Up", "ucla-wordpress-plugin"),
        value: "chevron-up",
      },
      {
        label: __("Chevron Down", "ucla-wordpress-plugin"),
        value: "chevron-down",
      },
      {
        label: __("Chevron Left", "ucla-wordpress-plugin"),
        value: "chevron-left",
      },
      {
        label: __("Chevron Right", "ucla-wordpress-plugin"),
        value: "chevron-right",
      },
      {
        label: __("Double Chevron Left", "ucla-wordpress-plugin"),
        value: "chevrons-left",
      },
      {
        label: __("Double Chevron Right", "ucla-wordpress-plugin"),
        value: "chevrons-right",
      },
      {
        label: __("Arrow Up", "ucla-wordpress-plugin"),
        value: "arrow-up",
      },
      {
        label: __("Arrow Down", "ucla-wordpress-plugin"),
        value: "arrow-down",
      },
      {
        label: __("Arrow Left", "ucla-wordpress-plugin"),
        value: "arrow-left",
      },
      {
        label: __("Arrow Right", "ucla-wordpress-plugin"),
        value: "arrow-right",
      },
      {
        label: __("Chat", "ucla-wordpress-plugin"),
        value: "chat",
      },
      {
        label: __("Comment", "ucla-wordpress-plugin"),
        value: "comment",
      },
      {
        label: __("Envelope", "ucla-wordpress-plugin"),
        value: "envelope",
      },
      {
        label: __("Location", "ucla-wordpress-plugin"),
        value: "location",
      },
      {
        label: __("User Circle", "ucla-wordpress-plugin"),
        value: "user-circle",
      },
      {
        label: __("User", "ucla-wordpress-plugin"),
        value: "user",
      },
      {
        label: __("Video Camera", "ucla-wordpress-plugin"),
        value: "video-camera",
      },
      {
        label: __("Facebook", "ucla-wordpress-plugin"),
        value: "facebook",
      },
      {
        label: __("Instagram", "ucla-wordpress-plugin"),
        value: "instagram",
      },
      {
        label: __("LinkedIn", "ucla-wordpress-plugin"),
        value: "linkedin",
      },
      {
        label: __("TikTok", "ucla-wordpress-plugin"),
        value: "tiktok",
      },
      {
        label: __("Twitter/X", "ucla-wordpress-plugin"),
        value: "twitter",
      },
      {
        label: __("YouTube", "ucla-wordpress-plugin"),
        value: "youtube",
      },
      {
        label: __("Check", "ucla-wordpress-plugin"),
        value: "check",
      },
      {
        label: __("Copy", "ucla-wordpress-plugin"),
        value: "copy",
      },
      {
        label: __("Download", "ucla-wordpress-plugin"),
        value: "download",
      },
      {
        label: __("Image", "ucla-wordpress-plugin"),
        value: "image",
      },
      {
        label: __("Image Gallery", "ucla-wordpress-plugin"),
        value: "image-gallery",
      },
      {
        label: __("External Link", "ucla-wordpress-plugin"),
        value: "link-external",
      },
      {
        label: __("Minus", "ucla-wordpress-plugin"),
        value: "minus",
      },
      {
        label: __("Plus", "ucla-wordpress-plugin"),
        value: "plus",
      },
      {
        label: __("Pause Circle", "ucla-wordpress-plugin"),
        value: "pause-circle",
      },
      {
        label: __("Play Circle", "ucla-wordpress-plugin"),
        value: "play-circle",
      },
      {
        label: __("Sort", "ucla-wordpress-plugin"),
        value: "sort",
      },
      {
        label: __("Sunny", "ucla-wordpress-plugin"),
        value: "sunny",
      },
      {
        label: __("Cloudy", "ucla-wordpress-plugin"),
        value: "cloudy",
      },
      {
        label: __("Partly Cloudy", "ucla-wordpress-plugin"),
        value: "partly-cloudy",
      },
      {
        label: __("Fog", "ucla-wordpress-plugin"),
        value: "fog",
      },
      {
        label: __("Windy", "ucla-wordpress-plugin"),
        value: "windy",
      },
      {
        label: __("Rain", "ucla-wordpress-plugin"),
        value: "rain",
      },
      {
        label: __("Thunderstorm", "ucla-wordpress-plugin"),
        value: "thunderstorm",
      },
      {
        label: __("Moon", "ucla-wordpress-plugin"),
        value: "moon",
      },
      {
        label: __("Full Moon", "ucla-wordpress-plugin"),
        value: "full-moon",
      },
      {
        label: __("Calendar", "ucla-wordpress-plugin"),
        value: "calendar",
      },
      {
        label: __("Clock", "ucla-wordpress-plugin"),
        value: "clock",
      },
      {
        label: __("Error", "ucla-wordpress-plugin"),
        value: "error",
      },
      {
        label: __("Information", "ucla-wordpress-plugin"),
        value: "information",
      },
      {
        label: __("Success", "ucla-wordpress-plugin"),
        value: "success",
      },
      {
        label: __("Warning", "ucla-wordpress-plugin"),
        value: "warning",
      },
    ];

    // console.log("withSidebarSelect", props);
    return (
      <>
        <BlockEdit {...props} />
        <InspectorControls>
          <PanelBody title={__("Button Settings")}>
            <SelectControl
              label={__("Select Icon")}
              value={buttonIcon}
              options={iconSelectOption}
              onChange={(value) => {
                setAttributes({
                  buttonIcon: value,
                });
              }}
              help={
                <>
                  <ExternalLink href="https://designsystem.brand.ucla.edu/build/v2.0.0-beta.2/docs/style-guide/iconography.html">
                    {__(
                      "See all available icons here.",
                      "ucla-wordpress-plugin"
                    )}
                  </ExternalLink>
                </>
              }
            />
            {buttonIcon && (
              <SelectControl
                value={buttonIconAlign}
                label={__("Align Icon")}
                options={[
                  {
                    label: __("Left", "ucla-wordpress-plugin"),
                    value: "lead",
                  },
                  {
                    label: __("Right", "ucla-wordpress-plugin"),
                    value: "trail",
                  },
                ]}
                onChange={(value) => {
                  setAttributes({
                    buttonIconAlign: value,
                  });
                }}
              />
            )}
          </PanelBody>
        </InspectorControls>
      </>
    );
  };
}, "withSidebarSelect");

wp.hooks.addFilter(
  "editor.BlockEdit",
  "ucla-wordpress-plugin/with-sidebar-select",
  withSidebarSelect
);

const withSidebarSelectProp = createHigherOrderComponent((BlockListBlock) => {
  return (props) => {
    // If current block is not allowed
    if (!enableSideBarOnBlocks.includes(props.name)) {
      return <BlockListBlock {...props} />;
    }

    // console.log("withSidebarSelectProp", props);
    const { attributes } = props;
    const { buttonIcon, buttonIconAlign } = attributes;
    if (buttonIcon) {
      return (
        <BlockListBlock
          {...props}
          className={`ucla-btn--icon ucla-icon--${buttonIcon} ucla-btn--icon-${buttonIconAlign}`}
        />
      );
    } else {
      return <BlockListBlock {...props} />;
    }
  };
}, "withSidebarSelectProp");

wp.hooks.addFilter(
  "editor.BlockListBlock",
  "ucla-wordpress-plugin/with-sidebar-select-prop",
  withSidebarSelectProp
);

const saveSidebarSelectAttribute = (extraProps, blockType, attributes) => {
  // Do nothing if it's another block than our defined ones.
  if (enableSideBarOnBlocks.includes(blockType.name)) {
    const { buttonIcon, buttonIconAlign } = attributes;
    if (buttonIcon) {
      extraProps.className = classnames(
        extraProps.className,
        `ucla-btn--icon ucla-icon--${buttonIcon} ucla-btn--icon-${buttonIconAlign}`
      );
    }
  }

  return extraProps;
};
wp.hooks.addFilter(
  "blocks.getSaveContent.extraProps",
  "ucla-wordpress-plugin/save-sidebar-select-attribute",
  saveSidebarSelectAttribute
);
