import { __ } from "@wordpress/i18n";
import {
  useBlockProps,
  useInnerBlocksProps,
  InnerBlocks,
  InspectorControls,
} from "@wordpress/block-editor";
import { PanelBody, RangeControl, CheckboxControl, TextareaControl } from "@wordpress/components";
import { useState } from '@wordpress/element';
import { Splide } from '@splidejs/react-splide';
import '@splidejs/react-splide/css/core';
import "./editor.scss";
const ALLOWED_BLOCKS = ["ucla-wordpress-plugin/carousel-slide"];
const TEMPLATE = [
  ["ucla-wordpress-plugin/carousel-slide", {}],
  ["ucla-wordpress-plugin/carousel-slide", {}],
];
const Edit = ({ attributes, setAttributes, isSelected }) => {
  let { perPage, perPageTablet, perPageMobile, ariaLabel } = attributes;
  const [ showBreakPoints, setShowBreakPoints ] = useState(perPageTablet || perPageMobile);
  const blockProps = useBlockProps();
  const {children, ...innerBlocksProps} = useInnerBlocksProps( blockProps,  {
    allowedBlocks: ALLOWED_BLOCKS,
    template: TEMPLATE,
    orientation: 'horizontal',
  })
  const onResponsiveChange = value => {
    setShowBreakPoints(!showBreakPoints);
    if (value) {
      setAttributes({perPageMobile: null, perPageTablet: null});
    }
  }
  return (
    <>
      <InspectorControls>
        <PanelBody title="Settings">
          <RangeControl
            label="Number of Items per slide"
            max={4}
            min={1}
            step={1}
            value={perPage}
            onChange={(value) => {
              setAttributes({ perPage: value });
            }}
          />
          {showBreakPoints &&
          <>
            <RangeControl
              label="Number of Items per slide on tablet"
              max={4}
              min={1}
              step={1}
              value={perPageTablet}
              onChange={(value) => {
                setAttributes({ perPageTablet: value });
              }}
            />
            <RangeControl
              label="Number of Items per slide on mobile"
              max={4}
              min={1}
              step={1}
              value={perPageMobile}
              onChange={(value) => {
                setAttributes({ perPageMobile: value });
              }}
            />
            </>
          }
          <CheckboxControl
            checked={showBreakPoints}
            onChange={()=>onResponsiveChange(showBreakPoints)}
            label="Responsive Slides"
            help="Change the number of slides on tablet or mobile"
          />
          <hr />
          <TextareaControl
            label="Aria Label"
            help="Describe the purpose of this carousel"
            value={ariaLabel}
            onChange={(value)=>setAttributes({ariaLabel: value})}
          />
        </PanelBody>
      </InspectorControls>
      <div {...innerBlocksProps}>
        <Splide options={{
          perPage: perPage,
          drag: false,
          arrows: false,
          updateOnMove: true,
          breakpoints: {
            960: {
              perPage: perPageTablet
            },
            768: {
              perPage: perPageMobile,
            }
          }
        }}>
          {children}
        </Splide>
        {isSelected &&
          <InnerBlocks.ButtonBlockAppender />
        }
      </div>
    </>
  );
};
export default Edit;
