import { __ } from "@wordpress/i18n";
/**
 * React hook that is used to mark the block wrapper element.
 * It provides all the necessary props like the class name.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/packages/packages-block-editor/#useblockprops
 */
import {
  useBlockProps,
  InspectorControls,
  RichText,
} from "@wordpress/block-editor";
import { PanelBody, SelectControl } from "@wordpress/components";

const Edit = ({ attributes, setAttributes }) => {
  let { ribbonVariant, ribbonContent } = attributes;
  const blockProps = useBlockProps();
  const onVariantChange = (variant) => {
    setAttributes({ ribbonVariant: variant });
  };
  return (
    <>
      <InspectorControls>
        <PanelBody title={__("Settings", "ucla-wordpress-plugin")} initialOpen>
          <SelectControl
            label={__("Select variant", "ucla-wordpress-plugin")}
            value={ribbonVariant}
            onChange={onVariantChange}
            help={__(
              "Change the variant of the ribbon.",
              "ucla-wordpress-plugin"
            )}
            options={[
              {
                value: "brand",
                label: __("Brand", "ucla-wordpess-plugin"),
              },
              {
                value: "highlight",
                label: __("Highlight", "ucla-wordpess-plugin"),
              },
            ]}
          />
        </PanelBody>
      </InspectorControls>
      <div {...blockProps}>
        <div className={`ucla-ribbon ucla-ribbon--${ribbonVariant}`}>
          <RichText
            className="ucla-ribbon__text"
            tagName={ribbonVariant === "brand" ? "h2" : "h3"}
            onChange={(content) => {
              setAttributes({ ribbonContent: content });
            }}
            value={ribbonContent}
            placeholder="Lorem ipsum dolor sit amet consectetuer adipiscing"
            preserveWhiteSpace={false}
          />
        </div>
      </div>
    </>
  );
};
export default Edit;
